==> download_v2.3.661.zip: download/include/download_changemydata.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains everything to change my data
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-12-07 FPG created the script
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


if ( (!empty($_POST['FANA'])) && (!empty($_POST['VONA'])) && (!empty($_POST['EMAIL'])) ) {
    $sQuery = "UPDATE USER SET ULAST = ?, UFIRST = ?, UEMAIL = ? WHERE UID = ?";
    $defaultErrorMsg=$lang['contactSysadmin'];
    $statement = mysqli_prepare($databaseConnection, $sQuery);
    setSession("GLASQLEXIT", logSQLError($sQuery));

    setSession("UFIRST", $_POST['VONA']);
    setSession("ULAST", $_POST['FANA']);
    setSession("UEMAIL", $_POST['EMAIL']);

    if (withoutSQLError()) {
        if (!mysqli_stmt_bind_param($statement, "sssi", $_POST['FANA'], $_POST['VONA'], $_POST['EMAIL'], getSession("UID"))) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    }
    closePreparedStatement($statement);
    header("Location: index.php");
} else {
    setSession("GLAERRORMESSAGE", $lang['changemydatafillout']);
    header("Location: index.php?mode=changeperson");
}


?>

==> download_v3.0.681.zip: download/include/download_changemydata.php <==
<?php
######################################################################
# Authors: Franz-Peter Glawar <office@glawar.at>, 2014
#
# This php contains everything to change my data
#
#
# (c) www.glawar.at
#
######################################################################
####  History
#---------------------------------------------------------------------
# v2014-12-07 FPG created the script
######################################################################
####  Variables that should be adapted if necessary
####------------------------------------------------------------------
######################################################################
####  Variables that should not be changed
####------------------------------------------------------------------
######################################################################


if ( (!empty($_POST['FANA'])) && (!empty($_POST['VONA'])) && (!empty($_POST['EMAIL'])) ) {
    $sQuery = "UPDATE ".getDBTablePrefix()."USER SET ULAST = ?, UFIRST = ?, UEMAIL = ?, ULANG = ? WHERE UID = ?";
    $defaultErrorMsg=$lang['contactSysadmin'];
    $statement = mysqli_prepare($databaseConnection, $sQuery);
    setSession("GLASQLEXIT", logSQLError($sQuery));

    setSession("UFIRST", $_POST['VONA']);
    setSession("ULAST", $_POST['FANA']);
    setSession("UEMAIL", $_POST['EMAIL']);
    setSession("lang", $_POST['USERLANGUAGE']);

    if (withoutSQLError()) {
        if (!mysqli_stmt_bind_param($statement, "ssssi", $_POST['FANA'], $_POST['VONA'], $_POST['EMAIL'], $_POST['USERLANGUAGE'], getSession("UID"))) {
            setSession("GLASQLEXIT", logSQLErrorManual("Error binding input params with sql-statement: ".$sQuery));
        } else {
            mysqli_stmt_execute($statement);
        }
    }
    closePreparedStatement($statement);
    header("Location: index.php");
} else {
    setSession("GLAERRORMESSAGE", $lang['changemydatafillout']);
    header("Location: index.php?mode=changeperson");
}


?>
